@@ -5,6 +5,7 @@ from typing import Type, List
 
 from aiohttp import BasicAuth
 from http_tools.http_server_connector import HttpServerConnector
+from http_tools.retry import retry
 
 from .elements.abstract.selectable import Selectable
 from .elements.output_format import OutputFormat
@@ -40,7 +41,7 @@ class ClickHouseConnector:
     def __init__(self, config: Config, context: Context):
         self.config = config
         self._http_connector = HttpServerConnector(config, context)
-
+    @retry(attempts_limit=2, sleep_time_sec=2.0)
     async def execute(self, sql: str) -> str:
         logger.debug(f'sql({sql}):')
         request_start_time = time.time()
